@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# COPYRIGHT (C) 2021 Nicotine+ Team
+# COPYRIGHT (C) 2021-2022 Nicotine+ Contributors
 #
 # GNU GENERAL PUBLIC LICENSE
 #    Version 3, 29 June 2007
@@ -19,6 +19,7 @@
 
 import glob
 import os
+import subprocess
 
 
 def update_pot():
@@ -29,11 +30,11 @@ def update_pot():
              + sorted(glob.glob("pynicotine/**/*.py", recursive=True), key=os.path.abspath)
              + sorted(glob.glob("pynicotine/**/*.ui", recursive=True), key=os.path.abspath))
 
-    os.system("xgettext -o po/nicotine.pot " + " ".join(files))
+    subprocess.check_call(["xgettext", "-o", "po/nicotine.pot"] + files)
 
     # PLUGININFO files
     files = sorted(glob.glob("pynicotine/plugins/**/PLUGININFO", recursive=True))
-    os.system("xgettext --join-existing -L Python -o po/nicotine.pot " + " ".join(files))
+    subprocess.check_call(["xgettext", "--join-existing", "-L", "Python", "-o", "po/nicotine.pot"] + files)
 
 
 if __name__ == '__main__':
