@@ -1,4 +1,4 @@
-# COPYRIGHT (C) 2021 Nicotine+ Team
+# COPYRIGHT (C) 2021-2022 Nicotine+ Contributors
 #
 # GNU GENERAL PUBLIC LICENSE
 #    Version 3, 29 June 2007
@@ -21,18 +21,19 @@ import unittest
 from pynicotine.i18n import build_translations
 from pynicotine.i18n import get_translation_paths
 
-LANGUAGES = ("cs", "da", "de", "eo", "es_CL", "es_ES", "eu", "fi", "fr", "hu", "it", "lt", "nb_NO", "nl", "pl",
-             "pt_BR", "ru", "sk", "sv", "tr", "uk")
+LANGUAGES = ("ca", "cs", "da", "de", "eo", "es_CL", "es_ES", "eu", "fi", "fr", "hu", "it", "lt", "lv", "nb_NO", "nl",
+             "pl", "pt_BR", "ru", "sk", "sv", "tr", "uk", "zh_Hans")
 
 
 class I18nTest(unittest.TestCase):
 
-    @staticmethod
-    def test_build_translations():
+    def test_build_translations(self):
 
         languages = build_translations()
         mo_files = get_translation_paths()
 
         for lang in LANGUAGES:
-            assert lang in languages
-            assert ("share/locale/" + lang + "/LC_MESSAGES", ["mo/" + lang + "/LC_MESSAGES/nicotine.mo"]) in mo_files
+            self.assertIn(lang, languages)
+            self.assertIn(
+                ("share/locale/" + lang + "/LC_MESSAGES", ["mo/" + lang + "/LC_MESSAGES/nicotine.mo"]),
+                mo_files)
